@@ -23,8 +23,9 @@ class Subscription:
     def Data(self):
         """
         Returns a list of the data
-        Return self._data
         """
+        return  self._data
+
     def SetData(self, name, data):
         """
             Sets the class full of information
@@ -512,11 +513,10 @@ if __name__ == "__main__":
     from time import sleep
     import sys
     if "--version" in sys.argv :
-        print("0.0.1")
+        print("1.0.5")
         sys.exit()
 
 
-
     def _AddNames(lnames):
         for i in range(0, len(lnames)):
             item = str(lnames[i])
@@ -538,7 +538,7 @@ if __name__ == "__main__":
 
     XSUBS = ["Scanner1.moisture", "Scannner1.basiswt"]
     s1 = [11110, 0, 10, 100]
-\
+
     try:
         cBridge = stdcom(XHOST,
                         XPORT)  # start the ball rolling make the communication class if it fails we will die a death in lib
